<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>FastMenu</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Φόρμα</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Γρήγορες επιλογές</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Εκτεταμένη προβολή</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Ενοποιημένη προβολή</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Μόνο πρώτη</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Μόνο δεύτερη</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Αποθηκευμένες ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation>Ανεστραμμένα</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation>Αληθές</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation>Ψευδές</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
</context>
<context>
    <name>MonitorInfo</name>
    <message>
        <source>Laptop LCD Monitor</source>
        <translation type="vanished">Οθόνη LCD φορητού</translation>
    </message>
    <message>
        <source>External VGA Monitor</source>
        <translation type="vanished">Εξωτερική οθόνη VGA</translation>
    </message>
    <message>
        <source>VGA Monitor</source>
        <translation type="vanished">Οθόνη VGA</translation>
    </message>
    <message>
        <source>External DVI Monitor</source>
        <translation type="vanished">Εξωτερική οθόνη DVI</translation>
    </message>
    <message>
        <source>DVI Monitor</source>
        <translation type="vanished">Οθόνη DVI</translation>
    </message>
    <message>
        <source>TV</source>
        <translation type="vanished">Τηλεόραση</translation>
    </message>
    <message>
        <source>Default Monitor</source>
        <translation type="vanished">Οθόνη εξ ορισμού</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Διάλογος</translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Διατήρηση των οθονών συνδεδεμένων</translation>
    </message>
    <message>
        <source>Magnetic attraction</source>
        <translation type="vanished">Μαγνητική έλξη</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Unify all monitors</source>
        <translation type="vanished">Ενοποίηση όλων των οθονών</translation>
    </message>
    <message>
        <source>Monitor Position</source>
        <translation type="vanished">Θέση της οθόνης</translation>
    </message>
    <message>
        <source>Primary monitor:</source>
        <translation type="vanished">Πρωτεύουσα οθόνη:</translation>
    </message>
    <message>
        <source>Do you want to save changes?</source>
        <translation type="vanished">Επιθυμείτε την αποθήκευση των αλλαγών;</translation>
    </message>
    <message>
        <source>Please, check the settings before saving.</source>
        <translation type="vanished">Παρακαλώ, ελέγξτε τις ρυθμίσεις πριν την αποθήκευση.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="vanished">Όνομα</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Όνομα:</translation>
    </message>
    <message>
        <source>Actual</source>
        <translation type="vanished">Τρέχον</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>Γρήγορο μενού</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>Ορισμός θέσης</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Σφάλμα</translation>
    </message>
    <message>
        <source>Config can not be saved</source>
        <translation type="vanished">Δεν είναι δυνατή η αποθήκευση της διαμόρφωσης</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation>Προηγμένες ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <source>Turn on</source>
        <translation type="vanished">Ενεργοποίηση</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Ανάλυση:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Ενεργοποίηση αυτής της προβολής</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Αυτή είναι η πρωτεύουσα οθόνη μου</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Αυτή η οθόνη επεκτείνει μια άλλη προβολή</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Προηγμένες</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Ρυθμός ανανέωσης:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Περιστροφή:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Πληροφορίες</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Προβολή των πληροφοριών</translation>
    </message>
    <message>
        <source>Rate:</source>
        <translation type="vanished">Ρυθμός:</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation type="vanished">Hz</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">Θέση:</translation>
    </message>
    <message>
        <source>x:</source>
        <translation type="vanished">x:</translation>
    </message>
    <message>
        <source>y:</source>
        <translation type="vanished">y:</translation>
    </message>
    <message>
        <source>Brightness:</source>
        <translation type="vanished">Φωτεινότητα:</translation>
    </message>
    <message>
        <source>Gamma:</source>
        <translation type="vanished">Γάμμα:</translation>
    </message>
    <message>
        <source>:</source>
        <translation type="vanished">:</translation>
    </message>
    <message>
        <source>Backlight:</source>
        <translation type="vanished">Οπισθόφως:</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="vanished">Αυτόματο</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>Όνομα: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>Κατασκευαστής: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>Σειραϊκός: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Μέγεθος προβολής: %1εκ x %2εκ</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>Σειραϊκός αριθμός: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation>Αναγνωριστικό συσκευής EISA: %1</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation>Ουδέν</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation>Ανεστραμμένα</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="255"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Auto</source>
        <translation type="vanished">Αυτόματο</translation>
    </message>
    <message>
        <source>Monitor Settings</source>
        <translation type="vanished">Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="vanished">Γρήγορες επιλογές</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Save settings</source>
        <translation type="vanished">Αποθήκευση ρυθμίσεων</translation>
    </message>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Διαχείριση των αποθηκευμένων ρυθμίσεων</translation>
    </message>
</context>
<context>
    <name>QuickOptions</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="vanished">Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="vanished">Εμφάνιση της ίδιας οθόνης στην LCD του φορητού και στην εξωτερική οθόνη</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="vanished">Εκτεταμένη προβολή</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="vanished">Απενεργοποίηση της οθόνης LCD του φορητού και χρήση μόνον της εξωτερικής οθόνης</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="vanished">Απενεργοποίηση της εξωτερικής οθόνης και χρήση μόνον της οθόνης LCD του φορητού</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="vanished">Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Αποθήκευση</translation>
    </message>
    <message>
        <source>Saved settings</source>
        <translation type="vanished">Αποθηκευμένες ρυθμίσεις</translation>
    </message>
    <message>
        <source>All:</source>
        <translation type="vanished">Όλες:</translation>
    </message>
    <message>
        <source>Hardware compatible:</source>
        <translation type="vanished">Συμβατές με το υλικό:</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Μετονομασία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Διαγραφή</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="vanished">Όνομα</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Όνομα:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Οι ρυθμίσεις τροποποιήθηκαν</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Οι τρέχουσες ρυθμίσεις σας ικανοποιούν;</translation>
    </message>
    <message>
        <source>%1 second(s) remaining</source>
        <translation type="vanished">Υπολείπεται %1 δευτερόλεπτο(α)</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>Υπολείπεται %n δευτερόλεπτο(α)</numerusform>
            <numerusform>Υπολείπεται %n δευτερόλεπτο(α)</numerusform>
        </translation>
    </message>
</context>
</TS>
